/*
 *     SimSelect - Similarity-based Selection for 3D Surfaces
 *
 *     Authors : Emilie GUY, Jean-Marc THIERY and Tamy BOUBEKEUR
 *
 *     Copyright © 2012-2014 Telecom ParisTech - CNRS LTCI - Institut Mines Telecom
 *              All rights reserved
 *
 * This file is part of the SimSelect project
 *
 * SimSelect is free software: you can redistribute it and/or modify
 *
 * it under the terms of the GNU Lesser General Public License as published by
 *
 * the Free Software Foundation, either version 3 of the License, or
 *
 * (at your option) any later version.
 *
 * SimSelect is distributed in the hope that it will be useful,
 *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 *
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef PHONGSHADER_H
#define PHONGSHADER_H

#pragma once
#include "Shader.h"

class PhongShader : public Shader {
public:
    PhongShader (const std::string & vertexShaderFilename,
                 const std::string & fragmentShaderFilename) { init (vertexShaderFilename,fragmentShaderFilename); }
    inline virtual ~PhongShader () {}

    void setDiffuseRef (float s) {
        glUniform1f (diffuseRefLocation, s);
    }
    void setSpecRef (float s) {
        glUniform1f (specRefLocation, s);
    }

    void setShininess (float s) {
        glUniform1f (shininessLocation, s);
    }
    
private:
    void init (const std::string & vertexShaderFilename,
               const std::string & fragmentShaderFilename) {
        loadFromFile (vertexShaderFilename, fragmentShaderFilename);
        bind ();
        diffuseRefLocation = getUniLoc ("diffuseRef");
        specRefLocation = getUniLoc ("specRef");
        shininessLocation = getUniLoc ("shininess");
    }
    GLint diffuseRefLocation;
    GLint specRefLocation;
    GLint shininessLocation;
    GLint modeLocation;
};
#endif // PHONGSHADER_H
