/*
 *     SimSelect - Similarity-based Selection for 3D Surfaces
 *
 *     Authors : Emilie GUY, Jean-Marc THIERY and Tamy BOUBEKEUR
 *
 *     Copyright © 2012-2014 Telecom ParisTech - CNRS LTCI - Institut Mines Telecom
 *              All rights reserved
 *
 * This file is part of the SimSelect project
 *
 * SimSelect is free software: you can redistribute it and/or modify
 *
 * it under the terms of the GNU Lesser General Public License as published by
 *
 * the Free Software Foundation, either version 3 of the License, or
 *
 * (at your option) any later version.
 *
 * SimSelect is distributed in the hope that it will be useful,
 *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 *
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include "GLViewer.h"
#if 0 //(QT_VERSION < 5)
#include <QtGui/QStatusBar>
#include <QtGui/QWidget>
#include <QtGui/QGroupBox>
#include <QQtGui/GridLayout>
# else
#include <QStatusBar> // #include <QtGui/QStatusBar>
#include <QWidget> //#include <QtGui/QWidget>
#include <QGroupBox>//#include <QtGui/QGroupBox>
#include <QGridLayout> // #include <QQtGui/GridLayout>
#endif

#include <QAction>
#include <QMainWindow>
#include <QMenu>
#include <QMenuBar>
#include <QDir>
#include <QGLFormat>
#include <QPixmap>
#include <QSplashScreen>
#include <QString>
#include <string>
#include <QFileDialog>
#include "SelectionDock.h"
#include "VisuDock.h"

using namespace std;

/**
 * @brief The MainWindow class
 */
class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    MainWindow(int argc, char **argv);
protected:

    /**
     * @brief closeEvent
     * @param event
     */
    void closeEvent(QCloseEvent *event);
private:
    GLViewer* _viewer;
    bool _debugMode; /**< true if we are in debug mode */
    SelectionDock * _selectionDock; /**< dock that contains the selection /expansion tools */
    VisuDock* _visuDock; /**< dock for the debug mode,  gives more visual hints */
public slots:
    /**
     * @brief openMesh
     */
    void openMesh();

    /**
     * @brief openSVMselection
     */
    void openSVMselection();

    /**
     * @brief saveMesh
     */
    void saveMesh();

    /**
     * @brief openCamera
     */
    void openCamera();

    /**
     * @brief saveCamera
     */
    void saveCamera();

    /**
     * @brief loadSelections
     */
    void loadSelections();

    /**
     * @brief saveSelections
     */
    void saveSelections();

    /**
     * @brief setDebug if b == true we are in debug mode
     * @param b
     */
    void setDebug(bool b);

    /**
     * @brief chooseVideoName
     */
    void chooseVideoName();

    /**
     * @brief setTextToStatusBar print the text t at the bottom of the app
     * @param t
     */
    void setTextToStatusBar(QString t);

    /**
     * @brief saveTimings
     */
    void saveTimings();
};
#endif // MAINWINDOW_H
