/*
 *     SimSelect - Similarity-based Selection for 3D Surfaces
 *
 *     Authors : Emilie GUY, Jean-Marc THIERY and Tamy BOUBEKEUR
 *
 *     Copyright © 2012-2014 Telecom ParisTech - CNRS LTCI - Institut Mines Telecom
 *              All rights reserved
 *
 * This file is part of the SimSelect project
 *
 * SimSelect is free software: you can redistribute it and/or modify
 *
 * it under the terms of the GNU Lesser General Public License as published by
 *
 * the Free Software Foundation, either version 3 of the License, or
 *
 * (at your option) any later version.
 *
 * SimSelect is distributed in the hope that it will be useful,
 *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 *
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef VISUDOCK_H
#define VISUDOCK_H
#include <QDockWidget>
#include <QVBoxLayout>
#include <QButtonGroup>
#include <QCheckBox>
#include <QFrame>
#include <QLabel>
#include <QSlider>

#include "QSmartColorPicker.h"
#include "GLViewer.h"

/**
 * @brief The VisuDock class
 */
class VisuDock : public QDockWidget
{
    Q_OBJECT
public:
    VisuDock(const QString & title, GLViewer* viewer, QWidget* parent);

private:
    GLViewer* _viewer; /**< viewer of the app */
    QButtonGroup* visuBox; /**< group of buttons to change the visualization type (field, selection..) */
    QLabel* refHist; /**< reference histogram */
    QLabel* curHist; /**< histogram of the vertex under the mouse */
    QLabel* distHist; /**< distance between ref and curHist */

public slots:
    void updateRefHistogram();
    void updateCurHistogram();
    void changeTypeOfVisuDock(TYPE t);
};

#endif // VISUDOCK_H
